* PROGRAM :			replication_financial_incumbency_advantage.do
* AUTHORS :			Alexander Fouirnaies & Andrew Hall
* INFILE(S) :		
* OUTFILE(S) :		
* DATE WRITTEN :	1 DEC 2013
*************************************************************************

clear
program drop _all

gl path = "~/Dropbox/incumbency_campaign_finance"
*gl path = "~/Dropbox/research/incumbency_campaign_finance"

******************
** Figure 1: Share of total contributions
******************

cd "$path/replication_files"
use fouirnaies_hall_financial_incumbency_advantage, clear
*For federal and state elections, respectively, divide the running variable in to bins of size 1. 
gen bin=rv - mod(rv, 1) 
label define stateleveldefine 0 "US House" 1 "State Legislatures" 
label values statelevel stateleveldefine
*collapse date and keep the mean "dv_money" within each bin at federal and state levels, respectively.
collapse (mean) dv_money rv, by(bin statelevel)
* plot the mean dv_money for each bin
twoway scatter dv_money rv  if inrange(rv, -25,25), by(statelevel , row(1) graphregion(color(white)) ///
title("Effect of Incumbency on Democrats' Share of Contributions") note("") ) xline(0) ///
xtitle("Democratic Party's Vote Share Winning Margin" "(election t)") ///
ytitle("Democratic party's share of contributions" "(election t+1)") subtitle(, bcolor(white))

graph export partyshare_totalcontributions_federalandstate.eps , replace

******************
** Table 1
******************

cd "$path/replication_files"
estimates clear
use fouirnaies_hall_financial_incumbency_advantage, clear

*federal
*keep only federal level data
keep if statelevel==0
eststo: reg dv_money treat rv rv_treat if margin < 1, r
estadd scalar  Bandwidth= 1
estadd scalar  Level= 12345
eststo: reg dv_money treat rv rv_treat if margin < 3, r
estadd scalar  Bandwidth= 3
estadd scalar  Level= 12345
eststo: reg dv_money treat rv rv_treat if margin < 5, r
estadd scalar  Bandwidth= 5
estadd scalar  Level= 12345

*state
use fouirnaies_hall_financial_incumbency_advantage, clear
*keep only state level data
keep if statelevel==1
eststo: reg dv_money treat rv rv_treat if margin < 1, r
estadd scalar  Bandwidth= 1
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat if margin < 3, r
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat if margin < 5, r
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456

esttab using "Table1.tex", ///
substitute(Bandwidth "Bandwidth Pct." 12345 "Federal" 23456 "State"   \hline "\midrule") tex ///
star( ** 0.05)  scalar(Level Bandwidth N )  label  replace nonotes nomtitles nonumbers keep(treat _cons) fragment  ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)

********************************
*** Table 2 heterogeneity in treatment
********************************

cd "$path/replication_files"
estimates clear

**Analysis of Investors vs. Non-investors
*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
keep dv_investor* state dist year rv rv_treat treat margin
reshape long dv_investor , i(state dist year) j(investor)
gen investXdemwin = investor*treat
*** robust SE are larger than cluster SE, so we report robust
eststo: reg dv_investor  treat investXdemwin investor rv rv_treat if margin < 5, r
estadd scalar  Level= 34567
*state
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
keep dv_investor* state dist year rv rv_treat treat margin
gen election = _n
reshape long dv_investor , i(election) j(investor)
gen investXdemwin = treat*investor
*** robust SE are larger than cluster SE, so we report robust
eststo: reg dv_investor treat rv rv_treat investXdemwin investor  if margin < 5, r
estadd scalar  Level= 23456



**Analysis of Home state contributors vs. Out-of-state contributors
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
reshape long dv_home  , i(state dist year) j(homestate)
gen homeXdemwin = homestate*treat
*** robust SE are larger than cluster SE, so we report robust
eststo: reg dv_home  treat homeXdemwin homestate rv rv_treat   if margin < 5, r
estadd scalar  Level= 34567



**Analysis of Seniority
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
eststo: reg dv_money treat treatXdeminofficebefore deminofficebefore rv rv_treat   if margin < 5, r
estadd scalar  Level= 34567

esttab using "Table2.tex", ///
keep(treat investXdemwin investor homeXdemwin homestate treatXdeminofficebefore deminofficebefore  _cons) ///
substitute(98765 "full"  \hline "\midrule" 23456 "State" investor "Investor Contributor" investXdemwin "Investor Contribution $\times$ \\ Democrat Win (time t)" ///
34567  "Federal" demwinXdeminofficebefore "Held Office Once Before \\ $\times$ Democratic Win" deminofficebefore "Held Office Before" homestate ///
"Home State Contribution" homeXdemwin "Home State Contribution $\times$ \\ Democratic Win" )  ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)  star( ** 0.05)  scalar(Level N)  label replace nonotes nomtitles nonumbers fragment


********************************
*** Table 3 effect in levels
********************************

cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
keep dv_money_level_dem0 dv_money_level_dem1 dv_group_level_dem0 dv_group_level_dem1  state dist year rv treat 
reshape long dv_money_level_dem dv_group_level_dem, i(state dist year) j(demparty)
gen win=treat if demparty==1
replace win=1-treat if demparty==0
gen votesharemargin=rv  if demparty==1
replace votesharemargin= - rv  if demparty==0
gen winXvotesharemargin = votesharemargin*win
eststo: reg dv_money_level_dem win votesharemargin winXvotesharemargin  if abs(votesharemargin)<5 , r
estadd scalar  Level= 12345
eststo: reg dv_group_level_dem win votesharemargin winXvotesharemargin  if abs(votesharemargin)<5 , r
estadd scalar  Level= 12345

*state
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
keep dv_money_level_dem0 dv_money_level_dem1 dv_group_level_dem0 dv_group_level_dem1  state dist year rv treat chamber
reshape long dv_money_level_dem dv_group_level_dem, i(state chamber dist year) j(demparty)
gen win=treat if demparty==1
replace win=1-treat if demparty==0
gen votesharemargin=rv  if demparty==1
replace votesharemargin= - rv  if demparty==0
gen winXvotesharemargin = votesharemargin*win
eststo: reg dv_money_level_dem win votesharemargin winXvotesharemargin  if abs(votesharemargin)<5 , r
estadd scalar  Level= 12345
eststo: reg dv_group_level_dem win votesharemargin winXvotesharemargin  if abs(votesharemargin)<5 , r
estadd scalar  Level= 12345

*labels
label var win "Party Win \\ (time t)"
label var demparty "Democrat"

esttab using "Table3.tex", ///
keep(win _cons) substitute(12345 "Federal" 23456 "State" \hline "\midrule")  ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)  star(** 0.05)  scalar(Level N)  label replace nonotes nomtitles nonumbers fragment


**************************************************************************
******************** ONLINE APPENDIX *************************************
**************************************************************************


************************************************
**  Robustness Check: Including Additional Covariates
************************************************

cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
eststo: reg dv_money treat rv rv_treat  if margin < 3, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: xi: reg dv_money treat rv rv_treat dem_money_share i.state i.year if margin < 3, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
estadd scalar  Controls= 45678
eststo: reg dv_money treat rv rv_treat  if margin < 5, r
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456
eststo: xi: reg dv_money treat rv rv_treat dem_money_share i.state i.year if margin < 5, r 
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456
estadd scalar  Controls= 45678

*state
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
eststo: reg dv_money treat rv rv_treat  if margin < 3, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: xi: reg dv_money treat rv rv_treat dem_money_share i.state i.year lower if margin < 3, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
estadd scalar  Controls= 45678
eststo: reg dv_money treat rv rv_treat  if margin < 5, r
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456
eststo: xi: reg dv_money treat rv rv_treat dem_money_share i.state i.year lower if margin < 5, r 
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456
estadd scalar  Controls= 45678

esttab using "Table_covariates.tex", ///
keep(treat _cons) nomtitle ///
substitute( 45678 "\checkmark" Bandwidth "Bandwidth Pct." 12345 "Federal" 23456 "State"  \hline "\midrule" Standard "Robust standard") ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)  star(** 0.05 )  scalars(Level Bandwidth Controls N)  label replace nonotes nomtitles nonumbers fragment  


************************************************
**  Robustness Check: Fixed Effects
************************************************

cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
egen stateyear = concat(state year) 
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(state) r
estadd scalar  Level= 23456
estadd scalar FE= 34567
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(year) r 
estadd scalar  Level= 23456
estadd scalar FE = 45678
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(stateyear) r 
estadd scalar  Level= 23456
estadd scalar FE = 56789

*state
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
egen stateyear = concat(state year) 
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(state) r
estadd scalar  Level= 23456
estadd scalar FE= 34567
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(year) r 
estadd scalar  Level= 23456
estadd scalar FE = 45678
eststo: areg dv_money treat rv rv_treat  if margin < 5 , absorb(stateyear) r 
estadd scalar  Level= 23456
estadd scalar FE = 56789

esttab using "Table_fe.tex", ///
keep(treat _cons) substitute( 12345 "Federal" 23456 "State"   \hline "\midrule" FE "Fixed Effects" 34567 "State" 45678 "Year" 56789 "State-Year") ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)  star(** 0.05)  scalars(Level FE N)  label replace nonotes nomtitles nonumbers fragment   


********************************
*** Table: Donut test
********************************

cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0
gen donut = rv > -0.25 & rv < 0.25
eststo: reg dv_money treat rv rv_treat  if margin < 1 & donut==0, r 
estadd scalar  Bandwidth= 1
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat  if margin < 3 & donut==0, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat  if margin < 5 & donut==0, r 
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456

*state
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
gen donut = rv > -0.25 & rv < 0.25
eststo: reg dv_money treat rv rv_treat  if margin < 1 & donut==0, r 
estadd scalar  Bandwidth= 1
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat  if margin < 3 & donut==0, r 
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: reg dv_money treat rv rv_treat  if margin < 5 & donut==0, r 
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456

esttab using "Table_donut.tex", ///
keep(treat _cons) substitute(  Bandwidth "Bandwidth Pct." 12345 "Federal" 23456 "State"  \hline "\midrule" ) ///
b(%8.2f) se(%8.2f) sfmt(%8.0f)  star(** 0.05)  scalars(Level Bandwidth N)  label replace nonotes nomtitles nonumbers fragment   



********************************
*** Table Fixed effects for in-state/out-state donations
********************************


cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==0

reshape long dv_home  , i(state dist year) j(homestate)
gen homeXdemwin = homestate* treat

label var homeXdemwin "Home State Contribution $\times$ \\ Democrat Win (time t)"
label var homestate "Home State Contribution"

*Fixed effects
egen stateyear = concat(state year) 
eststo: areg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 5 , r absorb(state)
estadd scalar FE= 34567
estadd scalar  Bandwidth= 5
eststo: areg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 5 , r absorb(year)
estadd scalar FE = 45678
estadd scalar  Bandwidth= 5
eststo: areg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 5 , r absorb(stateyear)
estadd scalar FE = 56789
estadd scalar  Bandwidth= 5
*Donut
gen donut = rv > -0.25 & rv < 0.25
eststo: reg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 1 & donut==0,  robust
estadd scalar  Bandwidth= 1
estadd scalar Donut = 12345
eststo: reg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 3 & donut==0,  robust
estadd scalar  Bandwidth= 3
estadd scalar Donut = 12345
eststo: reg dv_home  treat homeXdemwin homestate rv rv_treat  if margin < 5 & donut==0,  robust
estadd scalar  Bandwidth= 5
estadd scalar Donut = 12345

esttab using "TableInOutStateRobust.tex", ///
keep(treat homeXdemwin homestate _cons) substitute( Bandwidth "Bandwidth Pct."  \hline "\midrule" FE "Fixed Effects" 34567 "State" 45678 "Year" 56789 "State-Year" 12345 "\checkmark") ///
b(%8.2f) se(%8.2f) sfmt(%8.0f) star(** 0.05)  scalars(Bandwidth FE Donut N)  label replace nonotes nomtitles nonumbers fragment   



********************************
*** Table: State Legislatures: Testing for Sorting
********************************

cd "$path/replication_files"
estimates clear

*federal
use fouirnaies_hall_financial_incumbency_advantage, clear
keep if statelevel==1
replace dem_money_share = 100*dem_money_share

eststo: reg dem_money_share treat rv rv_treat if margin < 1, r
estadd scalar  Bandwidth= 1
estadd scalar  Level= 23456
eststo: reg dem_money_share treat rv rv_treat if margin < 3, r
estadd scalar  Bandwidth= 3
estadd scalar  Level= 23456
eststo: reg dem_money_share treat rv rv_treat if margin < 5, r
estadd scalar  Bandwidth= 5
estadd scalar  Level= 23456

esttab using "Appendix_Placebo_stleg.tex", ///
keep(treat _cons) substitute(  Bandwidth "Bandwidth Pct." 12345 "Federal" 23456 "State"  \hline "\midrule" ) ///
se  star(** 0.05)  stats(Level Bandwidth N)  label replace nonotes nomtitles nonumbers fragment   













